==> qtjambi-qt3danimation-jre8-5.15.3-sources.jar: io/qt/qt3d/animation/QChannelMapper.java <==
package io.qt.qt3d.animation;


/**
 * <p>Allows to map the channels within the clip onto properties of objects in the application</p>
 * <p>Java wrapper for Qt class <a href="http://doc.qt.io/qt-5/qt3danimation-qchannelmapper.html">Qt3DAnimation::QChannelMapper</a></p>
 */
public class QChannelMapper extends io.qt.qt3d.core.QNode
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QChannelMapper.class);
    
    
    /**
     * <p>Overloaded constructor for {@link #QChannelMapper(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QChannelMapper() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    @SuppressWarnings({"exports"})
    public QChannelMapper(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QChannelMapper instance, io.qt.qt3d.core.QNode parent);
    
    @io.qt.QtUninvokable
    public final void addMapping(io.qt.qt3d.animation.QAbstractChannelMapping mapping){
        addMapping_native_Qt3DAnimation_QAbstractChannelMapping_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(mapping));
    }
    
    @io.qt.QtUninvokable
    private native void addMapping_native_Qt3DAnimation_QAbstractChannelMapping_ptr(long __this__nativeId, long mapping);
    
    @io.qt.QtUninvokable
    public final io.qt.core.QVector<io.qt.qt3d.animation.QAbstractChannelMapping> mappings(){
        return mappings_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QVector<io.qt.qt3d.animation.QAbstractChannelMapping> mappings_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void removeMapping(io.qt.qt3d.animation.QAbstractChannelMapping mapping){
        removeMapping_native_Qt3DAnimation_QAbstractChannelMapping_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(mapping));
    }
    
    @io.qt.QtUninvokable
    private native void removeMapping_native_Qt3DAnimation_QAbstractChannelMapping_ptr(long __this__nativeId, long mapping);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QChannelMapper(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QChannelMapper(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QChannelMapper instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-qt3danimation-jre8-6.2-sources.jar: io/qt/qt3d/animation/QChannelMapper.java <==
package io.qt.qt3d.animation;


/**
 * <p>Allows to map the channels within the clip onto properties of objects in the application</p>
 * <p>Java wrapper for Qt class <a href="https://doc.qt.io/qt/qt3danimation-qchannelmapper.html">Qt3DAnimation::QChannelMapper</a></p>
 */
public class QChannelMapper extends io.qt.qt3d.core.QNode
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QChannelMapper.class);
    
    
    /**
     * <p>Overloaded constructor for {@link #QChannelMapper(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QChannelMapper() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    @SuppressWarnings({"exports"})
    public QChannelMapper(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QChannelMapper instance, io.qt.qt3d.core.QNode parent);
    
    @io.qt.QtUninvokable
    public final void addMapping(io.qt.qt3d.animation.QAbstractChannelMapping mapping){
        addMapping_native_Qt3DAnimation_QAbstractChannelMapping_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(mapping));
    }
    
    @io.qt.QtUninvokable
    private native void addMapping_native_Qt3DAnimation_QAbstractChannelMapping_ptr(long __this__nativeId, long mapping);
    
    @io.qt.QtUninvokable
    public final io.qt.core.QList<io.qt.qt3d.animation.QAbstractChannelMapping> mappings(){
        return mappings_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QList<io.qt.qt3d.animation.QAbstractChannelMapping> mappings_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void removeMapping(io.qt.qt3d.animation.QAbstractChannelMapping mapping){
        removeMapping_native_Qt3DAnimation_QAbstractChannelMapping_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(mapping));
    }
    
    @io.qt.QtUninvokable
    private native void removeMapping_native_Qt3DAnimation_QAbstractChannelMapping_ptr(long __this__nativeId, long mapping);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QChannelMapper(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QChannelMapper(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QChannelMapper instance, QDeclarativeConstructor constructor);
    
}
